@@ -252,7 +252,7 @@ class AbstractBaseFlag(BaseModel):
                     }
                 )
                 cache = get_cache()
-                cache.add(self._cache_key(self.name), flag)
+                cache.set(self._cache_key(self.name), flag)
 
             return get_setting('FLAG_DEFAULT')
 
@@ -267,8 +267,13 @@ class AbstractBaseFlag(BaseModel):
 
         if self.testing:  # Testing mode is on.
             tc = get_setting('TEST_COOKIE') % self.name
+            th = tc.replace('_', '-')
+            on = None
             if tc in request.GET:
                 on = request.GET[tc] == '1'
+            elif th in request.headers:
+                on = request.headers[th] == '1'
+            if on is not None:
                 if not hasattr(request, 'waffle_tests'):
                     request.waffle_tests = {}
                 request.waffle_tests[self.name] = on
@@ -453,7 +458,7 @@ class Switch(BaseModel):
                     }
                 )
                 cache = get_cache()
-                cache.add(self._cache_key(self.name), switch)
+                cache.set(self._cache_key(self.name), switch)
 
             return get_setting('SWITCH_DEFAULT')
 
@@ -523,7 +528,7 @@ class Sample(BaseModel):
                     }
                 )
                 cache = get_cache()
-                cache.add(self._cache_key(self.name), sample)
+                cache.set(self._cache_key(self.name), sample)
 
             return get_setting('SAMPLE_DEFAULT')
         return Decimal(str(random.uniform(0, 100))) <= self.percent
