@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import logging
 import random
 import threading
@@ -164,6 +162,29 @@ class WaffleTests(TestCase):
         response = process_request(request, views.flag_in_view)
         self.assertEqual(b'off', response.content)
 
+    def test_remove_from_user(self):
+        """Same operation of `test_user` but performed with reverse relation"""
+        user = get_user_model().objects.create(username='foo')
+        flag = waffle.get_waffle_flag_model().objects.create(name='myflag')
+        flag.users.add(user)
+
+        request = get()
+        request.user = user
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'on', response.content)
+        assert 'dwf_myflag' not in response.cookies
+
+        request.user = get_user_model().objects.create(username='someone_else')
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'off', response.content)
+        assert 'dwf_myflag' not in response.cookies
+
+        # Unsetting the flag on a user should have an effect.
+        user.flag_set.remove(flag)
+        request.user = user
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'off', response.content)
+
     def test_group(self):
         """Test the per-group switch."""
         group = Group.objects.create(name='foo')
@@ -191,6 +212,33 @@ class WaffleTests(TestCase):
         response = process_request(request, views.flag_in_view)
         self.assertEqual(b'off', response.content)
 
+    def test_remove_from_group(self):
+        """Same operation of `test_group` but performed with reverse relation"""
+        group = Group.objects.create(name='foo')
+        user = get_user_model().objects.create(username='bar')
+        user.groups.add(group)
+
+        flag = waffle.get_waffle_flag_model().objects.create(name='myflag')
+        flag.groups.add(group)
+
+        request = get()
+        request.user = user
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'on', response.content)
+        assert 'dwf_myflag' not in response.cookies
+
+        request.user = get_user_model()(username='someone_else')
+        request.user.save()
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'off', response.content)
+        assert 'dwf_myflag' not in response.cookies
+
+        # Unsetting the flag on a group should have an effect.
+        group.flag_set.remove(flag)
+        request.user = user
+        response = process_request(request, views.flag_in_view)
+        self.assertEqual(b'off', response.content)
+
     def test_authenticated(self):
         """Test the authenticated/anonymous switch."""
         waffle.get_waffle_flag_model().objects.create(name='myflag', authenticated=True)
@@ -303,6 +351,22 @@ class WaffleTests(TestCase):
         assert not waffle.flag_is_active(request, 'foo')
         assert not hasattr(request, 'waffle_tests')
 
+    def test_testing_flag_header(self):
+        waffle.get_waffle_flag_model().objects.create(name='foo', testing=True)
+        request = RequestFactory().get('/foo', HTTP_DWFT_FOO='1')
+        request.user = AnonymousUser()
+        assert waffle.flag_is_active(request, 'foo')
+        assert 'foo' in request.waffle_tests
+        assert request.waffle_tests['foo']
+
+        # header should override cookie
+        request = RequestFactory().get('/foo', HTTP_DWFT_FOO='0')
+        request.user = AnonymousUser()
+        request.COOKIES['dwft_foo'] = 'True'
+        assert not waffle.flag_is_active(request, 'foo')
+        assert 'foo' in request.waffle_tests
+        assert not request.waffle_tests['foo']
+
     def test_set_then_unset_testing_flag(self):
         waffle.get_waffle_flag_model().objects.create(name='myflag', testing=True)
         response = self.client.get('/flag_in_view?dwft_myflag=1')
